@@ -46,6 +46,7 @@ enum {
 
 enum {
   ARG_0,
+  ARG_METADATA
 };
 
 static void 		gst_flacdec_class_init		(FlacDecClass *klass);
@@ -57,13 +58,21 @@ static GstElementStateReturn
 static const GstFormat* gst_flacdec_get_src_formats 	(GstPad *pad);
 static gboolean 	gst_flacdec_convert_src	 	(GstPad *pad, GstFormat src_format, gint64 src_value,
 		        				 GstFormat *dest_format, gint64 *dest_value);
-static const GstPadQueryType* 
+static const GstQueryType* 
 			gst_flacdec_get_src_query_types (GstPad *pad);
-static gboolean		gst_flacdec_src_query 		(GstPad *pad, GstPadQueryType type,
+static gboolean		gst_flacdec_src_query 		(GstPad *pad, GstQueryType type,
 	               					 GstFormat *format, gint64 *value);
 static const GstEventMask* 
 			gst_flacdec_get_src_event_masks (GstPad *pad);
 static gboolean 	gst_flacdec_src_event 		(GstPad *pad, GstEvent *event);
+static void             gst_flacdec_get_property        (GObject *object, 
+                                                         guint prop_id, 
+                                                         GValue *value, 
+                                                         GParamSpec *pspec);
+static void             gst_flacdec_set_property        (GObject *object, 
+                                                         guint prop_id, 
+                                                         const GValue *value, 
+                                                         GParamSpec *pspec);
 
 static FLAC__SeekableStreamDecoderReadStatus 	
 			gst_flacdec_read 		(const FLAC__SeekableStreamDecoder *decoder, 
@@ -120,11 +129,20 @@ static void
 gst_flacdec_class_init (FlacDecClass *klass) 
 {
   GstElementClass *gstelement_class;
+  GObjectClass *gobject_class;
 
   gstelement_class = (GstElementClass*)klass;
+  gobject_class = (GObjectClass*) klass;
 
   parent_class = g_type_class_ref(GST_TYPE_ELEMENT);
+	
+  g_object_class_install_property (gobject_class, ARG_METADATA,
+  g_param_spec_boxed ("metadata", "Metadata", "(logical) Stream metadata",
+                      GST_TYPE_CAPS, G_PARAM_READABLE));
 
+  gobject_class->get_property = gst_flacdec_get_property;
+  gobject_class->set_property = gst_flacdec_set_property;
+	
   gstelement_class->change_state = gst_flacdec_change_state;
 }
 
@@ -150,6 +168,7 @@ gst_flacdec_init (FlacDec *flacdec)
   flacdec->init = TRUE;
   flacdec->eos = FALSE;
   flacdec->seek_pending = FALSE;
+  flacdec->metadata = NULL;
 
   FLAC__seekable_stream_decoder_set_read_callback (flacdec->decoder, gst_flacdec_read);
   FLAC__seekable_stream_decoder_set_seek_callback (flacdec->decoder, gst_flacdec_seek);
@@ -167,20 +186,79 @@ gst_flacdec_init (FlacDec *flacdec)
 		 void *client_data))
 		(gst_flacdec_write));
 #endif
+  FLAC__seekable_stream_decoder_set_metadata_respond (flacdec->decoder, FLAC__METADATA_TYPE_VORBIS_COMMENT);
   FLAC__seekable_stream_decoder_set_metadata_callback (flacdec->decoder, gst_flacdec_metadata_callback);
   FLAC__seekable_stream_decoder_set_error_callback (flacdec->decoder, gst_flacdec_error_callback);
   FLAC__seekable_stream_decoder_set_client_data (flacdec->decoder, flacdec);
 }
 
+static gboolean
+gst_flacdec_update_metadata (FlacDec *flacdec, const FLAC__StreamMetadata *metadata)
+{
+  guint32 number_of_comments, cursor, str_len;
+  gchar *p_value, *value, *name, *str_ptr;
+  GstProps *props = NULL;
+  GstPropsEntry *entry;
+	
+  /* clear old one */
+  if (flacdec->metadata) {
+    gst_caps_unref (flacdec->metadata);
+    flacdec->metadata = NULL;
+  }
+
+  /* create props to hold the key/value pairs */
+  props = gst_props_empty_new ();
+  
+  number_of_comments = metadata->data.vorbis_comment.num_comments;
+  value = NULL;
+  GST_DEBUG (GST_CAT_CAPS, "%d tag(s) found",  number_of_comments);
+  for (cursor = 0; cursor < number_of_comments; cursor++)
+  {			
+    str_ptr = metadata->data.vorbis_comment.comments[cursor].entry;
+    str_len = GUINT32_FROM_LE (metadata->data.vorbis_comment.comments[cursor].length);
+    p_value = g_strstr_len ( str_ptr, str_len , "=" );
+    if (p_value)
+    {			
+      name = g_strndup (str_ptr, p_value - str_ptr);
+      value = g_strndup (p_value + 1, str_ptr + str_len - p_value);
+			
+      entry = gst_props_entry_new (name, GST_PROPS_STRING_TYPE, value);
+      gst_props_add_entry (props, (GstPropsEntry *) entry);
+
+      GST_DEBUG (GST_CAT_CAPS, "%s : %s", name, value);
+
+      g_free (name);
+      g_free (value);
+    }
+  }
+	
+  flacdec->metadata = gst_caps_new ("vorbisfile_metadata",
+                                    "application/x-gst-metadata",
+                                    props);
+  g_object_notify (G_OBJECT (flacdec), "metadata");
+	
+  return TRUE;
+}
+
 static void 
 gst_flacdec_metadata_callback (const FLAC__SeekableStreamDecoder *decoder,
 			       const FLAC__StreamMetadata *metadata, void *client_data)
 {
   FlacDec *flacdec;
-
+	
   flacdec = GST_FLACDEC (client_data);
 
-  flacdec->stream_samples = metadata->data.stream_info.total_samples;
+  switch (metadata->type)
+  {
+    case FLAC__METADATA_TYPE_STREAMINFO:
+         flacdec->stream_samples = metadata->data.stream_info.total_samples;
+ 	 break;
+    case FLAC__METADATA_TYPE_VORBIS_COMMENT:
+         gst_flacdec_update_metadata (flacdec, metadata);		  
+	 break;
+    default:
+         break;
+  }
 }
 
 static void 
@@ -220,7 +298,7 @@ gst_flacdec_seek (const FLAC__SeekableStreamDecoder *decoder,
 
   flacdec = GST_FLACDEC (client_data);
 
-  GST_DEBUG (0, "seek %lld\n", position);
+  GST_DEBUG (0, "seek %" G_GINT64_FORMAT, position);
   if (!gst_bytestream_seek (flacdec->bs, position, GST_SEEK_METHOD_SET)) {
     return FLAC__SEEKABLE_STREAM_DECODER_SEEK_STATUS_ERROR;
   }
@@ -239,11 +317,12 @@ gst_flacdec_tell (const FLAC__SeekableStreamDecoder *decoder,
   if (*position == -1)
     return FLAC__SEEKABLE_STREAM_DECODER_TELL_STATUS_ERROR;
 
-  GST_DEBUG (0, "tell %lld\n", *position);
+  GST_DEBUG (0, "tell %" G_GINT64_FORMAT, *position);
 
   return FLAC__SEEKABLE_STREAM_DECODER_TELL_STATUS_OK;
 }
 
+
 static FLAC__SeekableStreamDecoderLengthStatus 	
 gst_flacdec_length (const FLAC__SeekableStreamDecoder *decoder, 
 		    FLAC__uint64 *length, void *client_data)
@@ -256,7 +335,7 @@ gst_flacdec_length (const FLAC__SeekableStreamDecoder *decoder,
   if (*length == -1)
     return FLAC__SEEKABLE_STREAM_DECODER_TELL_STATUS_ERROR;
 
-  GST_DEBUG (0, "length %lld\n", *length);
+  GST_DEBUG (0, "length %" G_GINT64_FORMAT, *length);
 
   return FLAC__SEEKABLE_STREAM_DECODER_LENGTH_STATUS_OK;
 }
@@ -268,7 +347,7 @@ gst_flacdec_eof (const FLAC__SeekableStreamDecoder *decoder,
   FlacDec *flacdec;
 
   flacdec = GST_FLACDEC (client_data);
-  GST_DEBUG (0, "eof %d\n", flacdec->eos);
+  GST_DEBUG (0, "eof %d", flacdec->eos);
 
   return flacdec->eos;
 }
@@ -354,20 +433,22 @@ gst_flacdec_write (const FLAC__SeekableStreamDecoder *decoder,
       flacdec->total_samples = flacdec->seek_value;
     }
 
-    GST_DEBUG (0, "send discont");
+    if (GST_PAD_IS_USABLE (flacdec->srcpad)) {
+      GST_DEBUG (0, "send discont");
 
-    format = GST_FORMAT_TIME;
-    gst_pad_convert (flacdec->srcpad, GST_FORMAT_UNITS, flacdec->total_samples,
-		  &format, &time);
-    format = GST_FORMAT_BYTES;
-    gst_pad_convert (flacdec->srcpad, GST_FORMAT_UNITS, flacdec->total_samples,
-		  &format, &bytes);
-    discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, time,
+      format = GST_FORMAT_TIME;
+      gst_pad_convert (flacdec->srcpad, GST_FORMAT_UNITS,
+                       flacdec->total_samples, &format, &time);
+      format = GST_FORMAT_BYTES;
+      gst_pad_convert (flacdec->srcpad, GST_FORMAT_UNITS,
+                       flacdec->total_samples, &format, &bytes);
+      discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, time,
 		                         GST_FORMAT_BYTES, bytes,
 		                         GST_FORMAT_UNITS, flacdec->total_samples, 
 					 NULL);
 	  
-    gst_pad_push (flacdec->srcpad, GST_BUFFER (discont));
+      gst_pad_push (flacdec->srcpad, GST_BUFFER (discont));
+    }
   }
   
   if (!GST_PAD_CAPS (flacdec->srcpad)) {
@@ -390,38 +471,38 @@ gst_flacdec_write (const FLAC__SeekableStreamDecoder *decoder,
     flacdec->frequency = frame->header.sample_rate;
   }
 
-  outbuf = gst_buffer_new ();
-  GST_BUFFER_SIZE (outbuf) = samples * channels * ((depth+7)>>3);
-  GST_BUFFER_DATA (outbuf) = g_malloc (GST_BUFFER_SIZE (outbuf));
-  GST_BUFFER_TIMESTAMP (outbuf) = flacdec->total_samples * GST_SECOND / frame->header.sample_rate;
-
-  if (depth == 8) {
-    guint8 *outbuffer = (guint8 *)GST_BUFFER_DATA (outbuf);
-
-    for (i=0; i<samples; i++) {
-      for (j=0; j < channels; j++) {
-        *outbuffer++ = (guint8) buffer[j][i];
+  if (GST_PAD_IS_USABLE (flacdec->srcpad)) {
+    outbuf = gst_buffer_new ();
+    GST_BUFFER_SIZE (outbuf) = samples * channels * ((depth+7)>>3);
+    GST_BUFFER_DATA (outbuf) = g_malloc (GST_BUFFER_SIZE (outbuf));
+    GST_BUFFER_TIMESTAMP (outbuf) = flacdec->total_samples * GST_SECOND / frame->header.sample_rate;
+  
+    if (depth == 8) {
+      guint8 *outbuffer = (guint8 *)GST_BUFFER_DATA (outbuf);
+  
+      for (i=0; i<samples; i++) {
+        for (j=0; j < channels; j++) {
+          *outbuffer++ = (guint8) buffer[j][i];
+        }
       }
     }
-  }
-  else if (depth == 16) {
-    guint16 *outbuffer = (guint16 *)GST_BUFFER_DATA (outbuf);
-
-    for (i=0; i<samples; i++) {
-      for (j=0; j < channels; j++) {
-        *outbuffer++ = (guint16) buffer[j][i];
+    else if (depth == 16) {
+      guint16 *outbuffer = (guint16 *)GST_BUFFER_DATA (outbuf);
+  
+      for (i=0; i<samples; i++) {
+        for (j=0; j < channels; j++) {
+          *outbuffer++ = (guint16) buffer[j][i];
+        }
       }
     }
+    else {
+      g_warning ("flacdec: invalid depth %d found\n", depth);
+      return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
+    }
+    gst_pad_push (flacdec->srcpad, outbuf);
   }
-  else {
-    g_warning ("flacdec: invalid depth %d found\n", depth);
-    return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
-  }
-
   flacdec->total_samples += samples;
 
-  gst_pad_push (flacdec->srcpad, outbuf);
-
   return FLAC__STREAM_DECODER_WRITE_STATUS_CONTINUE;
 }
 
@@ -442,17 +523,17 @@ gst_flacdec_loop (GstElement *element)
   }
 
   if (flacdec->seek_pending) {
-    GST_DEBUG (GST_CAT_EVENT, "perform seek to sample %lld\n", 
+    GST_DEBUG (GST_CAT_EVENT, "perform seek to sample %" G_GINT64_FORMAT, 
 		              flacdec->seek_value);
 
     if (FLAC__seekable_stream_decoder_seek_absolute (flacdec->decoder, 
 			                             flacdec->seek_value)) 
     {
       flacdec->total_samples = flacdec->seek_value;
-      GST_DEBUG (GST_CAT_EVENT, "seek done\n");
+      GST_DEBUG (GST_CAT_EVENT, "seek done");
     }
     else {
-      GST_DEBUG (GST_CAT_EVENT, "seek failed\n");
+      GST_DEBUG (GST_CAT_EVENT, "seek failed");
     }
     flacdec->seek_pending = FALSE;
   }
@@ -469,14 +550,16 @@ gst_flacdec_loop (GstElement *element)
     FLAC__seekable_stream_decoder_finish(flacdec->decoder);
     flacdec->init = TRUE;
 
-    event = gst_event_new (GST_EVENT_EOS);
-    gst_pad_push (flacdec->srcpad, GST_BUFFER (event));
+    if (GST_PAD_IS_USABLE (flacdec->srcpad)) {
+      event = gst_event_new (GST_EVENT_EOS);
+      gst_pad_push (flacdec->srcpad, GST_BUFFER (event));
+    }
     gst_element_set_eos (element);
   }
    GST_DEBUG (GST_CAT_PLUGIN_INFO, "flacdec: _loop end");
 }
 
-GST_FORMATS_FUNCTION (gst_flacdec_get_src_formats,
+GST_PAD_FORMATS_FUNCTION (gst_flacdec_get_src_formats,
   GST_FORMAT_UNITS,
   GST_FORMAT_BYTES,
   GST_FORMAT_TIME
@@ -552,19 +635,19 @@ gst_flacdec_convert_src (GstPad *pad, GstFormat src_format, gint64 src_value,
 }
 
 GST_PAD_QUERY_TYPE_FUNCTION (gst_flacdec_get_src_query_types,
-  GST_PAD_QUERY_TOTAL,
-  GST_PAD_QUERY_POSITION
+  GST_QUERY_TOTAL,
+  GST_QUERY_POSITION
 )
 
 static gboolean
-gst_flacdec_src_query (GstPad *pad, GstPadQueryType type,
+gst_flacdec_src_query (GstPad *pad, GstQueryType type,
 	               GstFormat *format, gint64 *value)
 {
   gboolean res = TRUE;
   FlacDec *flacdec = GST_FLACDEC (gst_pad_get_parent (pad));
 
   switch (type) {
-    case GST_PAD_QUERY_TOTAL:
+    case GST_QUERY_TOTAL:
     {
       guint64 samples;
 
@@ -579,7 +662,7 @@ gst_flacdec_src_query (GstPad *pad, GstPadQueryType type,
 		       format, value);
       break;
     }
-    case GST_PAD_QUERY_POSITION:
+    case GST_QUERY_POSITION:
       gst_pad_convert (flacdec->srcpad, 
 		       GST_FORMAT_UNITS, 
 		       flacdec->total_samples, 
@@ -593,7 +676,7 @@ gst_flacdec_src_query (GstPad *pad, GstPadQueryType type,
   return res;
 }
 	  
-GST_EVENT_MASK_FUNCTION (gst_flacdec_get_src_event_masks,
+GST_PAD_EVENT_MASK_FUNCTION (gst_flacdec_get_src_event_masks,
     { GST_EVENT_SEEK, GST_SEEK_FLAG_ACCURATE }
 );
 
@@ -637,6 +720,7 @@ gst_flacdec_change_state (GstElement *element)
       flacdec->total_samples = 0;
       flacdec->init = TRUE;
       flacdec->eos = FALSE;
+      flacdec->metadata = NULL;
       break;
     case GST_STATE_PAUSED_TO_PLAYING:
       flacdec->eos = FALSE;
@@ -656,3 +740,37 @@ gst_flacdec_change_state (GstElement *element)
   return GST_STATE_SUCCESS;
 }
 
+static void
+gst_flacdec_set_property (GObject *object, guint prop_id, 
+                          const GValue *value, GParamSpec *pspec)
+{
+  FlacDec *flacdec;
+	      
+  g_return_if_fail (GST_IS_FLACDEC (object));
+
+  flacdec = GST_FLACDEC (object);
+
+  switch (prop_id) {
+    default:
+      g_warning ("Unknown property id\n");
+  }
+}
+
+static void 
+gst_flacdec_get_property (GObject *object, guint prop_id, 
+                          GValue *value, GParamSpec *pspec)
+{
+  FlacDec *flacdec;
+	      
+  g_return_if_fail (GST_IS_FLACDEC(object));
+
+  flacdec = GST_FLACDEC (object);
+
+  switch (prop_id) {
+    case ARG_METADATA:
+      g_value_set_boxed (value, flacdec->metadata);
+      break;
+    default:
+      g_warning ("Unknown property id\n");
+  }
+}
