@@ -846,6 +846,7 @@ static GstBuffer *gst_gnomevfssrc_get(GstPad *pad)
 	GnomeVFSResult result = 0;
 	GstBuffer *buf;
 	GnomeVFSFileSize readbytes;
+	guint8 *data;
 
 	g_return_val_if_fail(pad != NULL, NULL);
 	src = GST_GNOMEVFSSRC(gst_pad_get_parent(pad));
@@ -869,14 +870,14 @@ static GstBuffer *gst_gnomevfssrc_get(GstPad *pad)
 	if (src->iradio_mode && src->icy_metaint > 0) {
 		GST_BUFFER_DATA (buf) = g_malloc0 (src->icy_metaint);
 		g_return_val_if_fail (GST_BUFFER_DATA (buf) != NULL, NULL);
-
+		data = GST_BUFFER_DATA (buf);
 		GST_BUFFER_SIZE (buf) = 0;
 		/* FIXME GROSS HACK: We try to read in at least 8000
 		 * bytes of data so that mp3 typefinding will work. */
 		do
 		{
 			GST_DEBUG (0,"doing read: icy_count: %Lu", src->icy_count);
-			result = gnome_vfs_read (src->handle, GST_BUFFER_DATA (buf),
+			result = gnome_vfs_read (src->handle, data,
 						 src->icy_metaint - src->icy_count,
 						 &readbytes);
 
@@ -892,6 +893,7 @@ static GstBuffer *gst_gnomevfssrc_get(GstPad *pad)
 			GST_BUFFER_OFFSET (buf) = src->curoffset;
 			GST_BUFFER_SIZE (buf) += readbytes;
 			src->curoffset += readbytes;
+			data += readbytes;
 			
 			if (src->icy_count == src->icy_metaint) {
 				gst_gnomevfssrc_get_icy_metadata (src);
@@ -900,6 +902,7 @@ static GstBuffer *gst_gnomevfssrc_get(GstPad *pad)
 		} while (src->in_first_get
 			 && GST_BUFFER_OFFSET (buf) < 8000 &&
 			 src->icy_metaint - src->icy_count >= 8000);
+		src->in_first_get = FALSE;
 	} else {
 		/* allocate the space for the buffer data */
 		GST_BUFFER_DATA(buf) = g_malloc(src->bytes_per_read);
@@ -941,7 +944,7 @@ static GstBuffer *gst_gnomevfssrc_get(GstPad *pad)
 	}
 
 	GST_BUFFER_TIMESTAMP (buf) = -1;
-	src->in_first_get = FALSE;
+
 	/* we're done, return the buffer */
 	return buf;
 }
@@ -983,20 +986,11 @@ static gboolean gst_gnomevfssrc_open_file(GstGnomeVFSSrc *src)
 	
 	info = gnome_vfs_file_info_new ();
 	if (gnome_vfs_get_file_info_from_handle (src->handle, info,
-						 GNOME_VFS_FILE_INFO_DEFAULT | GNOME_VFS_FILE_INFO_GET_MIME_TYPE)
+						 GNOME_VFS_FILE_INFO_DEFAULT)
 	    == GNOME_VFS_OK)
 	{
 		if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE)
 			src->size = info->size;
-		if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE)
-		{
-			GstCaps *caps = gst_caps_new ("gnomevfssrc", info->mime_type, NULL);
-			GST_DEBUG (0, "got MIME type \"%s\", setting caps",
-				   info->mime_type);
-			gst_pad_try_set_caps (src->srcpad, caps);
-		}
-		else
-			GST_DEBUG (0, "No mime type available");
 	}
 	else
 		GST_DEBUG (0, "getting info failed: %s", gnome_vfs_result_to_string (result));
@@ -1009,6 +1003,8 @@ static gboolean gst_gnomevfssrc_open_file(GstGnomeVFSSrc *src)
 	
 	GST_DEBUG(0, "open result: %s", gnome_vfs_result_to_string (result));
 
+	src->in_first_get = TRUE;
+
 	GST_FLAG_SET(src, GST_GNOMEVFSSRC_OPEN);
 
 	return TRUE;
