@@ -145,7 +145,7 @@ gst_vorbisenc_class_init (VorbisEncClass * klass)
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_QUALITY, 
     g_param_spec_float ("quality", "Quality", 
 	    "Specify quality instead of specifying a particular bitrate.",
-	    -1.0, 10.0, QUALITY_DEFAULT, G_PARAM_READWRITE));
+	    0.0, 1.0, QUALITY_DEFAULT, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SERIAL, 
     g_param_spec_int ("serial", "Serial", "Specify a serial number for the stream. (-1 is random)",
 	    -1, G_MAXINT, -1, G_PARAM_READWRITE));
@@ -463,13 +463,16 @@ gst_vorbisenc_add_metadata (VorbisEnc *vorbisenc, GstCaps *caps)
     if (gst_props_entry_get_type (prop) == GST_PROPS_STRING_TYPE) {
       const gchar *name = gst_props_entry_get_name (prop);
       const gchar *value;
+      char *upper_name;
 
       gst_props_entry_get_string (prop, &value);
 
       if (!value || strlen (value) == 0)
 	continue;
 
-      vorbis_comment_add_tag (&vorbisenc->vc, g_strdup (name), g_strdup (value));
+      upper_name = g_ascii_strup (name, -1);
+      vorbis_comment_add_tag (&vorbisenc->vc, g_strdup (upper_name), g_strdup (value));
+      g_free (upper_name);
     }
   }
 }
