@@ -265,10 +265,12 @@ static gboolean
 gst_avi_demux_avih (GstAviDemux *avi_demux)
 {
   gst_riff_avih *avih;
+  guint8 *avihdata;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&avih, sizeof (gst_riff_avih));
+  got_bytes = gst_bytestream_peek_bytes (bs, &avihdata, sizeof (gst_riff_avih));
+  avih = (gst_riff_avih *) avihdata;
 
   if (got_bytes == sizeof (gst_riff_avih)) {
     avi_demux->avih.us_frame 	= GUINT32_FROM_LE (avih->us_frame);
@@ -311,10 +313,12 @@ static gboolean
 gst_avi_demux_strh (GstAviDemux *avi_demux)
 {
   gst_riff_strh *strh;
+  guint8 *strhdata;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&strh, sizeof (gst_riff_strh));
+  got_bytes = gst_bytestream_peek_bytes (bs, &strhdata, sizeof (gst_riff_strh));
+  strh = (gst_riff_strh *) strhdata;
 
   if (got_bytes == sizeof (gst_riff_strh)) {
     avi_stream_context *target;
@@ -379,20 +383,24 @@ static void
 gst_avi_demux_dmlh (GstAviDemux *avi_demux)
 {
   gst_riff_dmlh *dmlh;
+  guint8 *dmlhdata;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&dmlh, sizeof (gst_riff_dmlh));
+  got_bytes = gst_bytestream_peek_bytes (bs, &dmlhdata, sizeof (gst_riff_dmlh));
+  dmlh = (gst_riff_dmlh *) dmlhdata;
 }
 
 static void
 gst_avi_demux_strn (GstAviDemux *avi_demux, gint len)
 {
   gchar *name;
+  guint8 *namedata;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&name, len);
+  got_bytes = gst_bytestream_peek_bytes (bs, &namedata, len);
+  name = (gchar *) namedata;
   if (got_bytes != len)
     return;
 
@@ -403,13 +411,15 @@ static void
 gst_avi_demux_strf_vids (GstAviDemux *avi_demux)
 {
   gst_riff_strf_vids *strf;
+  guint8 *strfdata;
   GstPad *srcpad;
   GstCaps *newcaps = NULL, *capslist = NULL;
   avi_stream_context *stream;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&strf, sizeof (gst_riff_strf_vids));
+  got_bytes = gst_bytestream_peek_bytes (bs, &strfdata, sizeof (gst_riff_strf_vids));
+  strf = (gst_riff_strf_vids *) strfdata;
   if (got_bytes != sizeof (gst_riff_strf_vids))
     return;
 
@@ -503,13 +513,15 @@ static void
 gst_avi_demux_strf_auds (GstAviDemux *avi_demux)
 {
   gst_riff_strf_auds *strf;
+  guint8 *strfdata;
   GstPad *srcpad;
   GstCaps *newcaps = NULL, *capslist = NULL;
   avi_stream_context *stream;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&strf, sizeof (gst_riff_strf_auds));
+  got_bytes = gst_bytestream_peek_bytes (bs, &strfdata, sizeof (gst_riff_strf_auds));
+  strf = (gst_riff_strf_auds *) strfdata;
   if (got_bytes != sizeof (gst_riff_strf_auds))
     return;
 
@@ -606,13 +618,15 @@ static void
 gst_avi_demux_strf_iavs (GstAviDemux *avi_demux)
 {
   gst_riff_strf_iavs *strf;
+  guint8 *strfdata;
   GstPad *srcpad;
   GstCaps *newcaps = NULL, *capslist = NULL;
   avi_stream_context *stream;
   GstByteStream  *bs = avi_demux->bs;
   guint32 got_bytes;
 
-  got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **)&strf, sizeof (gst_riff_strf_iavs));
+  got_bytes = gst_bytestream_peek_bytes (bs, &strfdata, sizeof (gst_riff_strf_iavs));
+  strf = (gst_riff_strf_iavs *) strfdata;
   if (got_bytes != sizeof (gst_riff_strf_iavs))
     return;
 
@@ -686,6 +700,7 @@ gst_avi_demux_parse_index (GstAviDemux *avi_demux,
   guint32 got_bytes;
   gint i;
   gst_riff_index_entry *entry;
+  guint32 id;
 
   if (!gst_bytestream_seek (avi_demux->bs, filepos + offset, GST_SEEK_METHOD_SET)) {
     GST_INFO (GST_CAT_PLUGIN_INFO, "avidemux: could not seek to index");
@@ -709,7 +724,9 @@ gst_avi_demux_parse_index (GstAviDemux *avi_demux,
     goto end;
   }
 
-  if (gst_riff_fourcc_to_id (GST_BUFFER_DATA (buf)) != GST_RIFF_TAG_idx1) {
+  id = GUINT32_FROM_LE (*(guint32 *)GST_BUFFER_DATA (buf));
+
+  if (id != GST_RIFF_TAG_idx1) {
     GST_INFO (GST_CAT_PLUGIN_INFO, "avidemux: no index found");
     goto end;
   }
@@ -737,8 +754,10 @@ gst_avi_demux_parse_index (GstAviDemux *avi_demux,
     gint stream_nr;
     gst_avi_index_entry *target = &avi_demux->index_entries[i];
     GstFormat format;
-
-    stream_nr = CHUNKID_TO_STREAMNR (entry[i].id);
+    guint32 id;
+ 
+    id = GUINT32_FROM_LE (entry[i].id);
+    stream_nr = CHUNKID_TO_STREAMNR (id);
     if (stream_nr > avi_demux->num_streams || stream_nr < 0) {
       avi_demux->index_entries[i].stream_nr = -1;
       continue;
@@ -748,9 +767,9 @@ gst_avi_demux_parse_index (GstAviDemux *avi_demux,
     stream = &avi_demux->stream[stream_nr];
 
     target->index_nr = i;
-    target->flags    = entry[i].flags;
-    target->size     = entry[i].size;
-    target->offset   = entry[i].offset;
+    target->flags    = GUINT32_FROM_LE (entry[i].flags);
+    target->size     = GUINT32_FROM_LE (entry[i].size);
+    target->offset   = GUINT32_FROM_LE (entry[i].offset);
 
     /* figure out if the index is 0 based or relative to the MOVI start */
     if (i == 0) {
@@ -1227,11 +1246,13 @@ gst_avi_demux_loop (GstElement *element)
   pos = gst_bytestream_tell (bs);
   do {
     gst_riff_riff *temp_chunk;
+    guint8 *tempdata;
     guint32 skipsize;
 
     /* read first two dwords to get chunktype and size */
     while (TRUE) {
-      got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **) &temp_chunk, sizeof (gst_riff_chunk));
+      got_bytes = gst_bytestream_peek_bytes (bs, &tempdata, sizeof (gst_riff_chunk));
+      temp_chunk = (gst_riff_riff *) tempdata;
       if (got_bytes < sizeof (gst_riff_chunk)) {
         if (!gst_avi_demux_handle_sink_event (avi_demux))
           return;
@@ -1247,7 +1268,8 @@ gst_avi_demux_loop (GstElement *element)
       case GST_RIFF_TAG_LIST:
         /* read complete list chunk */
         while (TRUE) {
-          got_bytes = gst_bytestream_peek_bytes (bs, (guint8 **) &temp_chunk, sizeof (gst_riff_list));
+          got_bytes = gst_bytestream_peek_bytes (bs, &tempdata, sizeof (gst_riff_list));
+	  temp_chunk = (gst_riff_riff *) tempdata;
           if (got_bytes < sizeof (gst_riff_list)) {
             if (!gst_avi_demux_handle_sink_event (avi_demux))
               return;
@@ -1389,8 +1411,6 @@ gst_avi_demux_loop (GstElement *element)
 	        if (chunk.size) {
                   got_bytes = gst_bytestream_peek (avi_demux->bs, &buf, chunk.size);
 
-                  GST_BUFFER_TIMESTAMP (buf) = next_ts;
-
                   if (stream->need_flush) {
                     /* FIXME, do some flush event here */
                     stream->need_flush = FALSE;
@@ -1398,6 +1418,45 @@ gst_avi_demux_loop (GstElement *element)
 	          GST_DEBUG (0, "send stream %d: %lld %d %lld %08x", stream_id, next_ts, stream->current_frame - 1,
 			    stream->delay, chunk.size);
 
+#if (G_BYTE_ORDER == G_BIG_ENDIAN)
+                  /* bla bla byteswap */
+                  do {
+                    GstCaps *caps = gst_pad_get_caps (stream->pad);
+
+                    if (!strcmp (gst_caps_get_mime (caps), "audio/raw")) {
+                      gint width = 0;
+
+                      gst_caps_get_int (caps, "width", &width);
+
+                      if (width == 16) {
+                        int samp;
+                        gint16 *old_data = (gint16 *) GST_BUFFER_DATA (buf);
+                        gint16 *new_data;
+                        GstBuffer *newbuf;
+
+                        if (gst_buffer_needs_copy_on_write (buf)) {
+                          newbuf = gst_buffer_new_and_alloc (got_bytes);
+                          new_data = (gint16 *) GST_BUFFER_DATA (newbuf);
+                        } else {
+                          newbuf = buf;
+                          new_data = old_data;
+                        }
+
+                        for (samp = 0; samp < (got_bytes/2); samp++) {
+                          new_data[samp] = GINT16_FROM_LE (old_data[samp]);
+                        }
+
+                        if (newbuf != buf) {
+                          gst_buffer_unref (buf);
+                          buf = newbuf;
+                        }
+                      }
+                    }
+                  } while (0);
+#endif
+
+                  GST_BUFFER_TIMESTAMP (buf) = next_ts;
+
                   gst_pad_push(stream->pad, buf);
 	        }
               }
