@@ -223,7 +223,11 @@ gst_stereo2mono_chain (GstPad *pad,GstBuffer *buf)
       gst_stereo2mono_fast_16bit_chain(data,&mono_data,GST_BUFFER_SIZE(buf));
       break;
     case 8:
-      gst_stereo2mono_fast_8bit_chain((gint8*)data,(gint8**)&mono_data,GST_BUFFER_SIZE(buf));
+      {
+	gint8 *ptr;
+        gst_stereo2mono_fast_8bit_chain((gint8*)data,&ptr,GST_BUFFER_SIZE(buf));
+	mono_data = (guint16 *)ptr;
+      }
       break;
     default:
       gst_element_error (GST_ELEMENT (stereo), "stereo2mono: capsnego was never performed, bailing...");
