@@ -73,6 +73,7 @@ static void 		gst_udpsrc_set_property 	(GObject *object, guint prop_id,
 							 const GValue *value, GParamSpec *pspec);
 static void 		gst_udpsrc_get_property 	(GObject *object, guint prop_id, 
 							 GValue *value, GParamSpec *pspec);
+static void 		gst_udpsrc_set_clock 		(GstElement *element, GstClock *clock);
 
 static GstElementClass *parent_class = NULL;
 /*static guint gst_udpsrc_signals[LAST_SIGNAL] = { 0 }; */
@@ -123,8 +124,18 @@ gst_udpsrc_class_init (GstUDPSrc *klass)
   gobject_class->get_property = gst_udpsrc_get_property;
 
   gstelement_class->change_state = gst_udpsrc_change_state;
+  gstelement_class->set_clock = gst_udpsrc_set_clock;
 }
 
+static void
+gst_udpsrc_set_clock (GstElement *element, GstClock *clock)
+{
+  GstUDPSrc *udpsrc;
+	      
+  udpsrc = GST_UDPSRC (element);
+
+  udpsrc->clock = clock;
+}
 
 static void
 gst_udpsrc_init (GstUDPSrc *udpsrc)
@@ -136,6 +147,11 @@ gst_udpsrc_init (GstUDPSrc *udpsrc)
 
   udpsrc->port = UDP_DEFAULT_PORT;
   udpsrc->control = CONTROL_UDP;
+  udpsrc->clock = NULL;
+  udpsrc->sock = -1;
+  udpsrc->control_sock = -1;
+
+  udpsrc->first_buf = TRUE;
 }
 
 static GstBuffer*
@@ -156,18 +172,14 @@ gst_udpsrc_get (GstPad *pad)
 
   FD_ZERO (&read_fds);
   FD_SET (udpsrc->sock, &read_fds);
-  
   if (udpsrc->control != CONTROL_NONE) {
      FD_SET (udpsrc->control_sock, &read_fds);
-     max_sock = udpsrc->control_sock;
-  }
-
-  else {
-     max_sock = udpsrc->sock;
   }
+  max_sock = MAX(udpsrc->sock, udpsrc->control_sock);
 
   if (select (max_sock+1, &read_fds, NULL, NULL, NULL) > 0) {
-    if (FD_ISSET (udpsrc->control_sock, &read_fds)) {
+    if ((udpsrc->control_sock != -1) &&
+        FD_ISSET (udpsrc->control_sock, &read_fds)) {
 #ifndef GST_DISABLE_LOADSAVE
       guchar *buf;
       int ret;
@@ -189,6 +201,7 @@ gst_udpsrc_get (GstPad *pad)
       	    ret = read (fdread, buf, 1024*10);
 	    break;
     	case CONTROL_UDP:
+      	    len = sizeof (struct sockaddr);
       	    ret = recvfrom (udpsrc->control_sock, buf, 1024*10, 0, (struct sockaddr *)&tmpaddr, &len);
       	    if (ret < 0) {
 		perror ("recvfrom");
@@ -205,7 +218,8 @@ gst_udpsrc_get (GstPad *pad)
       doc = xmlParseMemory(buf, ret);
       caps = gst_caps_load_thyself(doc->xmlRootNode);
       
-      gst_pad_try_set_caps (udpsrc->srcpad, caps);
+      /* foward the connect, we don't signal back the result here... */
+      gst_pad_proxy_link (udpsrc->srcpad, caps);
 
 #endif
       g_free (buf);
@@ -216,6 +230,29 @@ gst_udpsrc_get (GstPad *pad)
       GST_BUFFER_DATA (outbuf) = g_malloc (24000);
       GST_BUFFER_SIZE (outbuf) = 24000;
 
+      if (udpsrc->first_buf) {
+  	if (udpsrc->clock) {
+	   GstClockTime current_time;
+      	   GstEvent *discont;
+
+	   current_time = gst_clock_get_time (udpsrc->clock);
+      	   
+	   GST_BUFFER_TIMESTAMP (outbuf) = current_time;
+
+      	   discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, 
+				current_time, NULL);
+
+      	   gst_pad_push (udpsrc->srcpad, GST_BUFFER (discont));
+	}
+
+	udpsrc->first_buf = FALSE;
+      }
+      
+      else {
+      	GST_BUFFER_TIMESTAMP (outbuf) = GST_CLOCK_TIME_NONE;
+      }
+
+      len = sizeof (struct sockaddr);
       numbytes = recvfrom (udpsrc->sock, GST_BUFFER_DATA (outbuf),
 		  GST_BUFFER_SIZE (outbuf), 0, (struct sockaddr *)&tmpaddr, &len);
 
@@ -287,8 +324,8 @@ gst_udpsrc_init_receive (GstUDPSrc *src)
 {
   guint bc_val;
   bzero (&src->myaddr, sizeof (src->myaddr));
-  src->myaddr.sin_family = AF_INET;         /* host byte order */
-  src->myaddr.sin_port = htons (src->port);     /* short, network byte order */
+  src->myaddr.sin_family = AF_INET;           /* host byte order */
+  src->myaddr.sin_port = htons (src->port);   /* short, network byte order */
   src->myaddr.sin_addr.s_addr = INADDR_ANY;
 
   if ((src->sock = socket (AF_INET, SOCK_DGRAM, 0)) == -1) {
@@ -357,8 +394,14 @@ gst_udpsrc_init_receive (GstUDPSrc *src)
 static void
 gst_udpsrc_close (GstUDPSrc *src)
 {
-  close (src->sock);
-  close (src->control_sock);
+  if (src->sock != -1) {
+    close (src->sock);
+    src->sock = -1;
+  }
+  if (src->control_sock != -1) {
+    close (src->control_sock);
+    src->control_sock = -1;
+  }
 
   GST_FLAG_UNSET (src, GST_UDPSRC_OPEN);
 }
