@@ -79,6 +79,8 @@ struct _GstWavParse {
   gint width;
 
   gint64 offset;
+  gint64 datastart;
+  gboolean need_discont;
 };
 
 struct _GstWavParseClass {
@@ -118,8 +120,9 @@ struct _GstWavParseFormat {
 #define GST_RIFF_IBM_FORMAT_MULAW           (0x0101)
 #define GST_RIFF_IBM_FORMAT_ALAW            (0x0102)
 #define GST_RIFF_IBM_FORMAT_ADPCM           (0x0103)
-#define GST_RIFF_WAVE_FORMAT_DIVX           (0x0160)
-#define GST_RIFF_WAVE_FORMAT_divx           (0x0161)
+#define GST_RIFF_WAVE_FORMAT_DIVX_WMAV1     (0x0160)
+#define GST_RIFF_WAVE_FORMAT_DIVX_WMAV2     (0x0161)
+#define GST_RIFF_WAVE_FORMAT_WMAV9          (0x0162)
 #define GST_RIFF_WAVE_FORMAT_VORBIS1        (0x674f)
 #define GST_RIFF_WAVE_FORMAT_VORBIS2        (0x6750)
 #define GST_RIFF_WAVE_FORMAT_VORBIS3        (0x6751)
