@@ -106,7 +106,7 @@ static void			gst_videosink_init		(GstVideoSink *sink);
 static void			gst_videosink_chain		(GstPad *pad, GstBuffer *buf);
 static void			gst_videosink_set_clock		(GstElement *element, GstClock *clock);
 static GstElementStateReturn	gst_videosink_change_state 	(GstElement *element);
-static GstPadConnectReturn	gst_videosink_sinkconnect	(GstPad *pad, GstCaps *caps);
+static GstPadLinkReturn	gst_videosink_sinkconnect	(GstPad *pad, GstCaps *caps);
 static GstCaps *		gst_videosink_getcaps		(GstPad *pad, GstCaps *caps);
 static GstBufferPool*		gst_videosink_get_bufferpool	(GstPad *pad);
 
@@ -211,7 +211,7 @@ gst_videosink_init (GstVideoSink *sink)
   sink->sinkpad = gst_pad_new_from_template (sink_template, "sink");
   gst_element_add_pad (GST_ELEMENT (sink), sink->sinkpad);
   gst_pad_set_chain_function (sink->sinkpad, gst_videosink_chain);
-  gst_pad_set_connect_function (sink->sinkpad, gst_videosink_sinkconnect);
+  gst_pad_set_link_function (sink->sinkpad, gst_videosink_sinkconnect);
   gst_pad_set_getcaps_function (sink->sinkpad, gst_videosink_getcaps);
   gst_pad_set_bufferpool_function (sink->sinkpad, gst_videosink_get_bufferpool);
 
@@ -338,7 +338,7 @@ gst_videosink_set_caps (GstVideoSink *sink, GstCaps *caps)
   }
   return FALSE;
 }
-static GstPadConnectReturn
+static GstPadLinkReturn
 gst_videosink_sinkconnect (GstPad *pad, GstCaps *caps)
 {
   GstVideoSink *sink;
@@ -348,12 +348,12 @@ gst_videosink_sinkconnect (GstPad *pad, GstCaps *caps)
 
   /* we are not going to act on variable caps */
   if (!GST_CAPS_IS_FIXED (caps))
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
   
   /* try to set the caps on the output */
   if (gst_videosink_set_caps (sink, caps) == FALSE)
   {
-    return GST_PAD_CONNECT_REFUSED;
+    return GST_PAD_LINK_REFUSED;
   }
   
   /* remember width & height */
@@ -371,7 +371,7 @@ gst_videosink_sinkconnect (GstPad *pad, GstCaps *caps)
   g_object_notify (G_OBJECT (sink), "height");
   g_object_thaw_notify (G_OBJECT (sink));
 
-  return GST_PAD_CONNECT_OK;
+  return GST_PAD_LINK_OK;
 }
 static GstCaps *
 gst_videosink_getcaps (GstPad *pad, GstCaps *caps)
