@@ -82,7 +82,7 @@ _gst_ximage_new (GstXWindow *window, int width, int height)
   
   new->width = width;
   new->height = height;
-  new->window = window;
+  GST_IMAGE_WINDOW (new) = window;
   new->visual = DefaultVisual(window->disp, window->screen_num); 
   new->endianness = (ImageByteOrder (window->disp) == LSBFirst) ? G_LITTLE_ENDIAN:G_BIG_ENDIAN;
 
@@ -146,6 +146,7 @@ _gst_ximage_new (GstXWindow *window, int width, int height)
     }
   }
   
+  _gst_xwindow_ref (window);
   return new;
 }
 
@@ -154,13 +155,14 @@ static void
 _gst_ximage_destroy (GstXImage *image)
 {
   if (image->SHMInfo.shmaddr)
-    XShmDetach(image->window->disp, &image->SHMInfo);
+    XShmDetach(GST_IMAGE_WINDOW (image)->disp, &image->SHMInfo);
   if (image->ximage)
     XDestroyImage(image->ximage);
   if (image->SHMInfo.shmaddr)
     shmdt(image->SHMInfo.shmaddr);
   if (image->SHMInfo.shmid > 0)
     shmctl(image->SHMInfo.shmid, IPC_RMID, 0);
+  _gst_xwindow_unref (GST_IMAGE_WINDOW (image));
   g_free (image);
 }
 
