@@ -64,58 +64,34 @@
 #include "gstxvimage.h"
 
 #ifdef HAVE_XVIDEO
+static GStaticMutex omg = G_STATIC_MUTEX_INIT; /* omg, static vars */
 static int ver, rel, req, ev, err;
 static int formats;
 static int adaptors; 
 static XvAdaptorInfo        *ai;
 static XvImageFormatValues  *fo;
-static int im_adaptor = -1, im_port = -1;
-static int im_format = -1;
+static int im_adaptor, im_port, im_format;
 #endif
 static GstCaps *capslist = NULL;
-/* 
- * Desc: query the server for support for the MIT_SHM extension
- * Return:  0 = not available
- *          1 = shared XImage support available
- *          2 = shared Pixmap support available also
- */
-/* defined but not used
-static int
-_gst_xvimage_check_xshm(void)
-{
-#ifdef USE_SHM
-  int major, minor, ignore;
-  Bool pixmaps;
-  Display *display = XOpenDisplay(NULL);
-  
-  if (display == NULL)
-    return 0;
 
-  if (XQueryExtension(display, "MIT-SHM", &ignore, &ignore, &ignore)) 
-    {
-      if (XShmQueryVersion(display, &major, &minor, &pixmaps )==True) 
-	{
-	  return (pixmaps==True) ? 2 : 1;
-	}
-    }
-#endif
-  return 0;
-}
-*/
 
 static void 	_gst_xvimage_destroy 		(GstXvImage *image);
 static void 	_gst_xvimage_put		(GstXWindow *window, GstXvImage *image);
 
 gboolean
-_gst_xvimage_check_xvideo(void)
+_gst_xvimage_check_xvideo(Display *display)
 {
 #ifdef HAVE_XVIDEO
-  Display *display = XOpenDisplay(NULL);
+  g_static_mutex_lock (&omg);
+  display = XOpenDisplay(NULL);
 
-  if (display == NULL)
+  if (display == NULL) {
+    g_static_mutex_unlock (&omg);
     return FALSE;
+  }
 
   if (Success == XvQueryExtension(display,&ver,&rel,&req,&ev,&err)) {
+    g_static_mutex_unlock (&omg);
     return TRUE;
   }
 #endif /* HAVE_XVIDEO */
@@ -125,30 +101,32 @@ _gst_xvimage_check_xvideo(void)
 GstCaps*
 _gst_xvimage_get_capslist (void)
 {
-  return capslist;
+  return gst_caps_ref (capslist);
 }
 
 void
-_gst_xvimage_init(void)
+_gst_xvimage_init(Display *display)
 {
 #ifdef HAVE_XVIDEO
   int i;
     
-  Display *display = XOpenDisplay(NULL);
-
   if (display == NULL)
     return;
 
-  if (!_gst_xvimage_check_xvideo()) {
+  if (!_gst_xvimage_check_xvideo(display)) {
     g_warning("Xv: Server has no Xvideo extention support\n");
     return;
   }
+  g_static_mutex_lock (&omg);
+  im_adaptor = im_port = im_format = -1;
   if (Success != XvQueryAdaptors(display,DefaultRootWindow(display),&adaptors,&ai)) {
-    g_error("Xv: XvQueryAdaptors failed");
+    g_warning ("Xv: XvQueryAdaptors failed");
+    g_static_mutex_unlock (&omg);
     return;
   }
   GST_INFO(GST_CAT_PLUGIN_INFO, "Xv: %d adaptors available.",adaptors);
 
+  capslist = NULL;
   for (i = 0; i < adaptors; i++) {
     GST_INFO(GST_CAT_PLUGIN_INFO, "Xv: %s:%s%s%s%s%s, ports %ld-%ld",
                      ai[i].name,
@@ -223,6 +201,7 @@ _gst_xvimage_init(void)
       }
     }
   }
+  g_static_mutex_unlock (&omg);
 #else
   g_warning ("compiled without Xvideo extension support\n");
 #endif
@@ -241,20 +220,23 @@ _gst_xvimage_new (GstXvImageType  type,
   gint i;
   gboolean have_xv_scale = FALSE;
 
+  g_static_mutex_lock (&omg);
+
   image = g_new (GstXvImage, 1);
 
   GST_IMAGE_TYPE (image) 	= GST_TYPE_XVIMAGE;
   GST_IMAGE_DESTROYFUNC (image) = (GstImageDestroyFunc) _gst_xvimage_destroy;
   GST_IMAGE_PUTFUNC (image) 	= (GstImagePutFunc) _gst_xvimage_put;
+  GST_IMAGE_WINDOW (image)      = window;
 
   image->type = type;
   image->width = width;
   image->height = height;
-  image->window = window;
 
   /* *** image scaler port *** */
   if (im_port == -1) {
     GST_INFO(GST_CAT_PLUGIN_INFO, "Xv: no usable hw scaler port found");
+    g_static_mutex_unlock (&omg);
     return NULL;
   } else {
     fo = XvListImageFormats(window->disp, im_port, &formats);
@@ -267,6 +249,7 @@ _gst_xvimage_new (GstXvImageType  type,
     if (!have_xv_scale) {
       GST_INFO(GST_CAT_PLUGIN_INFO,"Xv: no usable image format found (port %d)",
                    im_port);
+      g_static_mutex_unlock (&omg);
       return NULL;
     }
   }
@@ -284,6 +267,7 @@ _gst_xvimage_new (GstXvImageType  type,
     g_warning ("XvShmCreateImage failed");
 	  
     g_free (image);
+    g_static_mutex_unlock (&omg);
     return NULL;
   }
     
@@ -299,6 +283,7 @@ _gst_xvimage_new (GstXvImageType  type,
     g_free (image->x_shm_info);
     g_free (image);
 
+    g_static_mutex_unlock (&omg);
     return NULL;
   }
 
@@ -316,6 +301,7 @@ _gst_xvimage_new (GstXvImageType  type,
     g_free (image->x_shm_info);
     g_free (image);
 
+    g_static_mutex_unlock (&omg);
     return NULL;
   }
 
@@ -333,6 +319,7 @@ _gst_xvimage_new (GstXvImageType  type,
     g_free (image);
 
 
+    g_static_mutex_unlock (&omg);
     return NULL;
   }
 	      
@@ -350,13 +337,15 @@ _gst_xvimage_new (GstXvImageType  type,
     GST_IMAGE_SIZE (image) = image->ximage->data_size;
   }
 
+  g_static_mutex_unlock (&omg);
+  _gst_xwindow_ref (window);
   return image;
 #else
-  g_error ("compiled without shared memory support: Xv image creation not supported");
+  g_warning ("compiled without shared memory support: Xv image creation not supported");
   return NULL;
 #endif /* USE_SHM */
 #else
-  g_error ("compiled without Xvideo extention support\n");
+  g_warning ("compiled without Xvideo extention support\n");
 #endif
   return NULL; /* well tell me if it's wrong to do this */
 }
@@ -371,7 +360,7 @@ _gst_xvimage_destroy (GstXvImage *image)
   g_return_if_fail (image != NULL);
 
 #ifdef USE_SHM
-  XShmDetach (image->window->disp, image->x_shm_info);
+  XShmDetach (GST_IMAGE_WINDOW (image)->disp, image->x_shm_info);
   XFree (image->ximage);
 
   x_shm_info = image->x_shm_info;
@@ -379,6 +368,8 @@ _gst_xvimage_destroy (GstXvImage *image)
       
   g_free (image->x_shm_info);
 
+  _gst_xwindow_unref (GST_IMAGE_WINDOW (image));
+
 #else /* USE_SHM */
   g_error ("trying to destroy shared memory image when gst was compiled without shared memory support");
 #endif /* USE_SHM */
